@@ -1,19 +1,20 @@
 #' Size of objects taking most memory use
 #'
-#' Displays the largest objects in memUse.
+#' Displays the largest objects in memory
+#'.
 #' @param n Positive integer: Maximum number of objects to display.
 #' @param orderBy Either \code{'size'} (default) or \code{'name'}.
 #' @param decreasing Logical, if \code{TRUE} (default), objects are displayed from largest to smallest.
-#' @param pos Environment from which to obtain size of objects. Default is 1. See \code{\link{ls}}.#"
-#' @param display If \code{TRUE} (default), print a table with memUse used.
+#' @param pos Environment from which to obtain size of objects. Default is 1. See \code{\link{ls}}.
 #' @param ... Other arguments to pass to \code{\link{ls}}.
-#' @return Data frame (invisible).
+#'
+#' @returns Data frame.
 #' @examples
 #' memUse()
 #' memUse(3)
 #' @export
 
-memUse <- function(n=10, orderBy='size', decreasing=TRUE, pos=1, display = TRUE, ...) {
+memUse <- function(n=10, orderBy='size', decreasing=TRUE, pos=1, ...) {
 
 	out <- sapply(ls(pos=pos, ...), function(x){ utils::object.size(get(x)) })
 	if (length(out) == 0) {
@@ -29,7 +30,6 @@ memUse <- function(n=10, orderBy='size', decreasing=TRUE, pos=1, display = TRUE,
 		out <- as.data.frame(out)
 		colnames(out) <- 'size'
 	}
-	if (display) print(out)
-	invisible(out)
+	out
 
 }
